@@ -2,6 +2,7 @@ import shutil
 import sys
 import textwrap
 from io import StringIO
+from typing import List
 
 import pytest
 
@@ -18,6 +19,11 @@ from check_python_versions.sources.setup_py import (
     update_setup_py_keyword,
     update_supported_python_versions,
 )
+from check_python_versions.versions import Version
+
+
+def v(versions: List[str]) -> List[Version]:
+    return [Version.from_string(v) for v in versions]
 
 
 def test_get_supported_python_versions(tmp_path):
@@ -29,10 +35,11 @@ def test_get_supported_python_versions(tmp_path):
             classifiers=[
                 'Programming Language :: Python :: 2.7',
                 'Programming Language :: Python :: 3.6',
+                'Programming Language :: Python :: 3.10',
             ],
         )
     """))
-    assert get_supported_python_versions(filename) == ['2.7', '3.6']
+    assert get_supported_python_versions(filename) == v(['2.7', '3.6', '3.10'])
 
 
 def test_get_supported_python_versions_computed(tmp_path):
@@ -47,7 +54,7 @@ def test_get_supported_python_versions_computed(tmp_path):
             ],
         )
     """))
-    assert get_supported_python_versions(filename) == ['2.7', '3.7']
+    assert get_supported_python_versions(filename) == v(['2.7', '3.7'])
 
 
 def test_get_supported_python_versions_string(tmp_path, capsys):
@@ -98,27 +105,27 @@ def test_get_versions_from_classifiers():
         'Programming Language :: Python :: 3.7',
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy',
-    ]) == ['2.7', '3.6', '3.7', 'PyPy']
+    ]) == v(['2.7', '3.6', '3.7', 'PyPy'])
 
 
 def test_get_versions_from_classifiers_major_only():
     assert get_versions_from_classifiers([
         'Programming Language :: Python :: 2',
         'Programming Language :: Python :: 3',
-    ]) == ['2', '3']
+    ]) == v(['2', '3'])
 
 
 def test_get_versions_from_classifiers_with_only_suffix():
     assert get_versions_from_classifiers([
         'Programming Language :: Python :: 2 :: Only',
-    ]) == ['2']
+    ]) == v(['2'])
 
 
 def test_get_versions_from_classifiers_with_trailing_whitespace():
     # I was surprised too that this is allowed!
     assert get_versions_from_classifiers([
         'Programming Language :: Python :: 3.6 ',
-    ]) == ['3.6']
+    ]) == v(['3.6'])
 
 
 def test_update_classifiers():
@@ -136,7 +143,7 @@ def test_update_classifiers():
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy',
         'Typing :: Typed',
-    ], ['2.7', '3.7']) == [
+    ], v(['2.7', '3.7', '3.10'])) == [
         'Development Status :: 4 - Beta',
         'Environment :: Console',
         'Intended Audience :: Developers',
@@ -146,6 +153,7 @@ def test_update_classifiers():
         'Programming Language :: Python :: 2.7',
         'Programming Language :: Python :: 3',
         'Programming Language :: Python :: 3.7',
+        'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy',
         'Typing :: Typed',
@@ -167,7 +175,7 @@ def test_update_classifiers_drop_major():
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy',
         'Typing :: Typed',
-    ], ['3.6', '3.7']) == [
+    ], v(['3.6', '3.7'])) == [
         'Development Status :: 4 - Beta',
         'Environment :: Console',
         'Intended Audience :: Developers',
@@ -195,7 +203,7 @@ def test_update_classifiers_no_major():
         'Programming Language :: Python :: Implementation :: CPython',
         'Programming Language :: Python :: Implementation :: PyPy',
         'Typing :: Typed',
-    ], ['2.7', '3.7']) == [
+    ], v(['2.7', '3.7'])) == [
         'Development Status :: 4 - Beta',
         'Environment :: Console',
         'Intended Audience :: Developers',
@@ -216,7 +224,7 @@ def test_update_classifiers_none_were_present():
         'Intended Audience :: Developers',
         'License :: OSI Approved :: GNU General Public License (GPL)',
         'Operating System :: OS Independent',
-    ], ['2.7', '3.7']) == [
+    ], v(['2.7', '3.7'])) == [
         'Development Status :: 4 - Beta',
         'Environment :: Console',
         'Intended Audience :: Developers',
@@ -239,7 +247,8 @@ def test_update_supported_python_versions_not_literal(tmp_path, capsys):
             ],
         )
     """))
-    assert update_supported_python_versions(filename, ['3.7', '3.8']) is None
+    assert update_supported_python_versions(filename,
+                                            v(['3.7', '3.8'])) is None
     assert (
         'Non-literal classifiers= passed to setup()'
         in capsys.readouterr().err
@@ -258,7 +267,8 @@ def test_update_supported_python_versions_not_a_list(tmp_path, capsys):
             ''',
         )
     """))
-    assert update_supported_python_versions(filename, ['3.7', '3.8']) is None
+    assert update_supported_python_versions(filename,
+                                            v(['3.7', '3.8'])) is None
     assert (
         'The value passed to setup(classifiers=...) is not a list'
         in capsys.readouterr().err
@@ -275,7 +285,11 @@ def test_get_python_requires(tmp_path, fix_max_python_3_version):
         )
     """))
     fix_max_python_3_version(7)
-    assert get_python_requires(setup_py) == ['3.6', '3.7']
+    assert get_python_requires(setup_py) == v(['3.6', '3.7'])
+    fix_max_python_3_version(10)
+    assert get_python_requires(setup_py) == v([
+        '3.6', '3.7', '3.8', '3.9', '3.10',
+    ])
 
 
 def test_get_python_requires_not_specified(tmp_path, capsys):
@@ -356,7 +370,8 @@ def test_update_python_requires(tmp_path, fix_max_python_3_version):
             python_requires='>= 3.4',
         )
     """))
-    result = update_python_requires(filename, ['3.5', '3.6', '3.7'])
+    result = update_python_requires(filename, v(['3.5', '3.6', '3.7']))
+    assert result is not None
     assert "".join(result) == textwrap.dedent("""\
         from setuptools import setup
         setup(
@@ -376,7 +391,8 @@ def test_update_python_requires_file_object(fix_max_python_3_version):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['3.5', '3.6', '3.7'])
+    result = update_python_requires(fp, v(['3.5', '3.6', '3.7']))
+    assert result is not None
     assert "".join(result) == textwrap.dedent("""\
         from setuptools import setup
         setup(
@@ -394,7 +410,7 @@ def test_update_python_requires_when_missing(capsys):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['3.5', '3.6', '3.7'])
+    result = update_python_requires(fp, v(['3.5', '3.6', '3.7']))
     assert result is None
     assert capsys.readouterr().err == ""
 
@@ -409,7 +425,7 @@ def test_update_python_requires_preserves_style(fix_max_python_3_version):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['2.7', '3.2'])
+    result = update_python_requires(fp, v(['2.7', '3.2']))
     assert "".join(result) == textwrap.dedent("""\
         from setuptools import setup
         setup(
@@ -432,7 +448,8 @@ def test_update_python_requires_multiline(fix_max_python_3_version):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['2.7', '3.2'])
+    result = update_python_requires(fp, v(['2.7', '3.2']))
+    assert result is not None
     assert "".join(result) == textwrap.dedent("""\
         from setuptools import setup
         setup(
@@ -459,7 +476,8 @@ def test_update_python_requires_multiline_variations(fix_max_python_3_version):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['2.7', '3.2'])
+    result = update_python_requires(fp, v(['2.7', '3.2']))
+    assert result is not None
     assert "".join(result) == textwrap.dedent("""\
         from setuptools import setup
         setup(
@@ -484,7 +502,7 @@ def test_update_python_requires_multiline_error(capsys):
         )
     """))
     fp.name = "setup.py"
-    result = update_python_requires(fp, ['2.7', '3.2'])
+    result = update_python_requires(fp, v(['2.7', '3.2']))
     assert result == fp.getvalue().splitlines(True)
     assert (
         "Did not understand python_requires= formatting in setup() call"
@@ -497,7 +515,7 @@ def test_update_python_requires_multiline_error(capsys):
     ('~= 2.7.12', ['2.7']),
 ])
 def test_parse_python_requires_approximately(constraint, result):
-    assert parse_python_requires(constraint) == result
+    assert parse_python_requires(constraint) == v(result)
 
 
 def test_parse_python_requires_approximately_not_enough_dots(capsys):
@@ -518,12 +536,12 @@ def test_parse_python_requires_approximately_not_enough_dots(capsys):
     ('== 3', ['3.0']),
 ])
 def test_parse_python_requires_matching_version(constraint, result):
-    assert parse_python_requires(constraint) == result
+    assert parse_python_requires(constraint) == v(result)
 
 
 def test_parse_python_requires_greater_than(fix_max_python_3_version):
     fix_max_python_3_version(8)
-    assert parse_python_requires('>= 3.6') == ['3.6', '3.7', '3.8']
+    assert parse_python_requires('>= 3.6') == v(['3.6', '3.7', '3.8'])
 
 
 @pytest.mark.parametrize('constraint, result', [
@@ -542,12 +560,12 @@ def test_parse_python_requires_greater_than_with_exceptions(
     fix_max_python_3_version, constraint, result
 ):
     fix_max_python_3_version(3)
-    assert parse_python_requires(constraint) == result
+    assert parse_python_requires(constraint) == v(result)
 
 
 def test_parse_python_requires_multiple_greater_than(fix_max_python_3_version):
     fix_max_python_3_version(7)
-    assert parse_python_requires('>= 2.7, >= 3.6') == ['3.6', '3.7']
+    assert parse_python_requires('>= 2.7, >= 3.6') == v(['3.6', '3.7'])
 
 
 @pytest.mark.parametrize('constraint, result', [
@@ -559,7 +577,7 @@ def test_parse_python_requires_multiple_greater_than(fix_max_python_3_version):
     ('> 2.7.12, < 3.0.1', ['2.7', '3.0']),
 ])
 def test_parse_python_requires_exclusive_ordering(constraint, result):
-    assert parse_python_requires(constraint) == result
+    assert parse_python_requires(constraint) == v(result)
 
 
 @pytest.mark.parametrize('constraint, result', [
@@ -568,7 +586,7 @@ def test_parse_python_requires_exclusive_ordering(constraint, result):
     ('=== 3', []),
 ])
 def test_parse_python_requires_arbitrary_version(constraint, result):
-    assert parse_python_requires(constraint) == result
+    assert parse_python_requires(constraint) == v(result)
 
 
 @pytest.mark.parametrize('op', ['~=', '>=', '<=', '>', '<', '==='])
@@ -601,12 +619,24 @@ def test_parse_python_requires_syntax_errors(capsys, specifier):
     (['3.6', '3.7'], '>=3.6'),
     (['2.7', '3.4', '3.5', '3.6', '3.7'],
      '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*'),
+    (['3.7'], '>=3.7'),
 ])
 def test_compute_python_requires(versions, expected, fix_max_python_3_version):
     fix_max_python_3_version(7)
-    result = compute_python_requires(versions)
+    result = compute_python_requires(v(versions))
+    assert result == expected
+    assert parse_python_requires(result) == v(versions)
+
+
+@pytest.mark.parametrize('versions, expected', [
+    (['3.9', '3.10'], '>=3.9'),
+    (['3.10', '3.11'], '>=3.10'),
+])
+def test_compute_python_requires_3_10(versions, expected,
+                                      fix_max_python_3_version):
+    fix_max_python_3_version(10)
+    result = compute_python_requires(v(versions))
     assert result == expected
-    assert parse_python_requires(result) == versions
 
 
 @pytest.mark.parametrize(['available', 'chosen'], [
